# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: statistics.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import expression_pb2 as expression__pb2
from . import data_type_pb2 as data__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10statistics.proto\x12\x08\x63z.proto\x1a\x10\x65xpression.proto\x1a\x0f\x64\x61ta_type.proto\"\x18\n\x08SortKeys\x12\x0c\n\x04keys\x18\x01 \x03(\r\"\x83\x01\n\x0b\x46ieldBounds\x12\x31\n\x06\x62ounds\x18\x01 \x03(\x0b\x32!.cz.proto.FieldBounds.BoundsEntry\x1a\x41\n\x0b\x42oundsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.cz.proto.Constant:\x02\x38\x01\"\x93\x02\n\tStatsData\x12\x13\n\x0bsnapshot_id\x18\x01 \x01(\x03\x12\x1a\n\rsize_in_bytes\x18\x02 \x01(\x03H\x00\x88\x01\x01\x12\x19\n\x0crecord_count\x18\x03 \x01(\x03H\x01\x88\x01\x01\x12+\n\x0c\x66ields_stats\x18\x05 \x01(\x0b\x32\x15.cz.proto.FieldsStats\x12\x34\n\x15sort_key_lower_bounds\x18\x0c \x01(\x0b\x32\x15.cz.proto.FieldBounds\x12\x34\n\x15sort_key_upper_bounds\x18\r \x01(\x0b\x32\x15.cz.proto.FieldBoundsB\x10\n\x0e_size_in_bytesB\x0f\n\r_record_count\"8\n\x0b\x46ieldsStats\x12)\n\x0b\x66ield_stats\x18\x01 \x03(\x0b\x32\x14.cz.proto.FieldStats\"N\n\nFieldStats\x12\x10\n\x08\x66ield_id\x18\x01 \x03(\r\x12.\n\x0bstats_value\x18\x02 \x03(\x0b\x32\x19.cz.proto.FieldStatsValue\"\xfa\x02\n\x0f\x46ieldStatsValue\x12\x13\n\tnan_count\x18\x01 \x01(\x03H\x00\x12\x15\n\x0bvalue_count\x18\x02 \x01(\x03H\x00\x12\x14\n\nnull_count\x18\x03 \x01(\x03H\x00\x12*\n\x0clower_bounds\x18\x04 \x01(\x0b\x32\x12.cz.proto.ConstantH\x00\x12*\n\x0cupper_bounds\x18\x05 \x01(\x0b\x32\x12.cz.proto.ConstantH\x00\x12\x12\n\x08\x61vg_size\x18\x06 \x01(\x01H\x00\x12\x12\n\x08max_size\x18\x07 \x01(\x03H\x00\x12\x19\n\x0f\x63ompressed_size\x18\x08 \x01(\x03H\x00\x12\x19\n\x0f\x64istinct_number\x18\t \x01(\x03H\x00\x12\x1f\n\x05top_k\x18\n \x01(\x0b\x32\x0e.cz.proto.TopKH\x00\x12(\n\thistogram\x18\x0b \x01(\x0b\x32\x13.cz.proto.HistogramH\x00\x12\x1b\n\x11raw_size_in_bytes\x18\x0c \x01(\x03H\x00\x42\x07\n\x05value\")\n\x04TopK\x12!\n\x05top_k\x18\x01 \x03(\x0b\x32\x12.cz.proto.Constant\"x\n\x0fHistogramBucket\x12\'\n\x0blower_bound\x18\x01 \x01(\x0b\x32\x12.cz.proto.Constant\x12\'\n\x0bupper_bound\x18\x02 \x01(\x0b\x32\x12.cz.proto.Constant\x12\x13\n\x0bvalue_count\x18\x03 \x01(\x03\"7\n\tHistogram\x12*\n\x07\x62uckets\x18\x01 \x03(\x0b\x32\x19.cz.proto.HistogramBucket\"0\n\nValuePoint\x12\"\n\x06values\x18\x01 \x03(\x0b\x32\x12.cz.proto.Constant\"l\n\rBoundaryPoint\x12\x10\n\x08included\x18\x01 \x01(\x08\x12\x13\n\tunbounded\x18\x02 \x01(\x08H\x00\x12+\n\x0bvalue_point\x18\x03 \x01(\x0b\x32\x14.cz.proto.ValuePointH\x00\x42\x07\n\x05value\"Z\n\x08\x42oundary\x12&\n\x05lower\x18\x01 \x01(\x0b\x32\x17.cz.proto.BoundaryPoint\x12&\n\x05upper\x18\x02 \x01(\x0b\x32\x17.cz.proto.BoundaryPoint\"b\n\rRangeBoundary\x12\n\n\x02id\x18\x01 \x01(\x04\x12!\n\x05types\x18\x02 \x03(\x0b\x32\x12.cz.proto.DataType\x12\"\n\x06ranges\x18\x03 \x03(\x0b\x32\x12.cz.proto.Boundary\"R\n\x0f\x45nforceBoundary\x12\x12\n\ntable_name\x18\x01 \x01(\t\x12+\n\nboundaries\x18\x02 \x01(\x0b\x32\x17.cz.proto.RangeBoundary\"D\n\rTableBoundary\x12\x33\n\x10table_boundaries\x18\x01 \x03(\x0b\x32\x19.cz.proto.EnforceBoundary\"c\n\nFieldRange\x12\x10\n\x08\x66ield_id\x18\x01 \x01(\r\x12 \n\x04type\x18\x02 \x01(\x0b\x32\x12.cz.proto.DataType\x12!\n\x05range\x18\x03 \x01(\x0b\x32\x12.cz.proto.BoundaryB\x02P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'statistics_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'P\001'
  _globals['_FIELDBOUNDS_BOUNDSENTRY']._options = None
  _globals['_FIELDBOUNDS_BOUNDSENTRY']._serialized_options = b'8\001'
  _globals['_SORTKEYS']._serialized_start=65
  _globals['_SORTKEYS']._serialized_end=89
  _globals['_FIELDBOUNDS']._serialized_start=92
  _globals['_FIELDBOUNDS']._serialized_end=223
  _globals['_FIELDBOUNDS_BOUNDSENTRY']._serialized_start=158
  _globals['_FIELDBOUNDS_BOUNDSENTRY']._serialized_end=223
  _globals['_STATSDATA']._serialized_start=226
  _globals['_STATSDATA']._serialized_end=501
  _globals['_FIELDSSTATS']._serialized_start=503
  _globals['_FIELDSSTATS']._serialized_end=559
  _globals['_FIELDSTATS']._serialized_start=561
  _globals['_FIELDSTATS']._serialized_end=639
  _globals['_FIELDSTATSVALUE']._serialized_start=642
  _globals['_FIELDSTATSVALUE']._serialized_end=1020
  _globals['_TOPK']._serialized_start=1022
  _globals['_TOPK']._serialized_end=1063
  _globals['_HISTOGRAMBUCKET']._serialized_start=1065
  _globals['_HISTOGRAMBUCKET']._serialized_end=1185
  _globals['_HISTOGRAM']._serialized_start=1187
  _globals['_HISTOGRAM']._serialized_end=1242
  _globals['_VALUEPOINT']._serialized_start=1244
  _globals['_VALUEPOINT']._serialized_end=1292
  _globals['_BOUNDARYPOINT']._serialized_start=1294
  _globals['_BOUNDARYPOINT']._serialized_end=1402
  _globals['_BOUNDARY']._serialized_start=1404
  _globals['_BOUNDARY']._serialized_end=1494
  _globals['_RANGEBOUNDARY']._serialized_start=1496
  _globals['_RANGEBOUNDARY']._serialized_end=1594
  _globals['_ENFORCEBOUNDARY']._serialized_start=1596
  _globals['_ENFORCEBOUNDARY']._serialized_end=1678
  _globals['_TABLEBOUNDARY']._serialized_start=1680
  _globals['_TABLEBOUNDARY']._serialized_end=1748
  _globals['_FIELDRANGE']._serialized_start=1750
  _globals['_FIELDRANGE']._serialized_end=1849
# @@protoc_insertion_point(module_scope)



from __future__ import absolute_import

import copy
import datetime
import functools
import operator
import typing
from typing import Any, Dict, Iterable, Iterator, List, Optional, Tuple, Union
import warnings

try:
    import pandas  # type: ignore
except ImportError:  # pragma: NO COVER
    pandas = None

import pyarrow  # type: ignore

from clickzetta.query_result import QueryResult


class Table(object):
    def __init__(self, workspace: str, table_name: str, instance: str,
                 vcluster: str):
        self.workspace = workspace
        self.table_name = table_name
        self.instance = instance
        self.vcluster = vcluster


class RowIterator(object):

    def __init__(
            self,
            query_result: QueryResult
    ):
        self.query_result = query_result

    @property
    def schema(self):
        return list(self._schema)

    @property
    def total_rows(self):
        return self.query_result.total_row_count

    def to_arrow_iterable(self
                          ) -> Iterator["pyarrow.RecordBatch"]:
        return self._to_page_iterable(self.query_result)

    # If changing the signature of this method, make sure to apply the same
    # changes to job.QueryJob.to_arrow()
    def to_arrow(self) -> "pyarrow.Table":

        try:
            record_batches = []
            for record_batch in self.to_arrow_iterable():
                record_batches.append(record_batch)
        finally:
            print('convert to pyarrow table successfully.')

        return pyarrow.Table.from_batches(record_batches)

    @staticmethod
    def __can_cast_timestamp_ns(column):
        try:
            column.cast("timestamp[ns]")
        except pyarrow.lib.ArrowInvalid:
            return False
        else:
            return True


class EmptyRowIterator(RowIterator):
    def __init__(
            self, query_result: QueryResult
    ):
        self.query_result = query_result

    def to_arrow(self) -> "pyarrow.Table":
        return pyarrow.Table.from_arrays(())

    def to_arrow_iterable(
            self,
            max_queue_size: Optional[int] = None,
    ) -> Iterator["pyarrow.RecordBatch"]:
        return iter((pyarrow.record_batch([]),))

    def __iter__(self):
        return iter(())



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: object_identifier.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17object_identifier.proto\x12\x08\x63z.proto\":\n\x0bObjectState\"+\n\x04Type\x12\n\n\x06ONLINE\x10\x00\x12\x0b\n\x07\x44\x45LETED\x10\x01\x12\n\n\x06STAGED\x10\x02\"\x90\x02\n\x10ObjectIdentifier\x12\"\n\x04type\x18\x01 \x01(\x0e\x32\x14.cz.proto.ObjectType\x12\x17\n\naccount_id\x18\x06 \x01(\x03H\x00\x88\x01\x01\x12\x19\n\x0c\x61\x63\x63ount_name\x18\x07 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x0binstance_id\x18\x02 \x01(\x03\x12\x1a\n\rinstance_name\x18\x05 \x01(\tH\x02\x88\x01\x01\x12\x11\n\tnamespace\x18\x03 \x03(\t\x12\x14\n\x0cnamespace_id\x18\n \x03(\x03\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\n\n\x02id\x18\t \x01(\x03\x42\r\n\x0b_account_idB\x0f\n\r_account_nameB\x10\n\x0e_instance_name\"G\n\x14ObjectIdentifierList\x12/\n\x0bidentifiers\x18\x01 \x03(\x0b\x32\x1a.cz.proto.ObjectIdentifier*\xe9\x01\n\nObjectType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08INSTANCE\x10\x01\x12\x12\n\x0eNETWORK_POLICY\x10\x02\x12\r\n\tWORKSPACE\x10\x64\x12\t\n\x05SHARE\x10\x65\x12\x0b\n\x06SCHEMA\x10\xc8\x01\x12\r\n\x08\x44\x41TALAKE\x10\xc9\x01\x12\t\n\x04USER\x10\xca\x01\x12\t\n\x04ROLE\x10\xcb\x01\x12\x13\n\x0fVIRTUAL_CLUSTER\x10h\x12\x08\n\x03JOB\x10\xcd\x01\x12\x0f\n\nCONNECTION\x10\xce\x01\x12\n\n\x05TABLE\x10\xac\x02\x12\r\n\x08\x46UNCTION\x10\xad\x02\x12\n\n\x05INDEX\x10\x90\x03\x12\t\n\x04\x46ILE\x10\xf4\x03*[\n\rPrincipalType\x12\x0b\n\x07PT_USER\x10\x00\x12\r\n\tPT_SYSTEM\x10\x01\x12\x15\n\x11PT_SERVICE_SYSTEM\x10\x02\x12\x17\n\x13PT_SERVICE_CUSTOMER\x10\x04\x42\x0c\n\x08\x63z.protoP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'object_identifier_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\010cz.protoP\001'
  _globals['_OBJECTTYPE']._serialized_start=446
  _globals['_OBJECTTYPE']._serialized_end=679
  _globals['_PRINCIPALTYPE']._serialized_start=681
  _globals['_PRINCIPALTYPE']._serialized_end=772
  _globals['_OBJECTSTATE']._serialized_start=37
  _globals['_OBJECTSTATE']._serialized_end=95
  _globals['_OBJECTSTATE_TYPE']._serialized_start=52
  _globals['_OBJECTSTATE_TYPE']._serialized_end=95
  _globals['_OBJECTIDENTIFIER']._serialized_start=98
  _globals['_OBJECTIDENTIFIER']._serialized_end=370
  _globals['_OBJECTIDENTIFIERLIST']._serialized_start=372
  _globals['_OBJECTIDENTIFIERLIST']._serialized_end=443
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: table_meta.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import table_common_pb2 as table__common__pb2
from . import object_identifier_pb2 as object__identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10table_meta.proto\x12\x08\x63z.proto\x1a\x12table_common.proto\x1a\x17object_identifier.proto\"S\n\x0fTableSchemaList\x12&\n\x07schemas\x18\x01 \x03(\x0b\x32\x15.cz.proto.TableSchema\x12\x18\n\x10highest_field_id\x18\x03 \x01(\r\"L\n\rFieldSpecList\x12\"\n\x05specs\x18\x01 \x03(\x0b\x32\x13.cz.proto.FieldSpec\x12\x17\n\x0f\x63urrent_spec_id\x18\x02 \x01(\r\"]\n\x16\x43ompositeFieldSpecList\x12*\n\tspec_list\x18\x01 \x03(\x0b\x32\x17.cz.proto.FieldSpecList\x12\x17\n\x0f\x63urrent_spec_id\x18\x02 \x01(\r\"=\n\x0c\x44\x61taFileInfo\x12\x11\n\tfile_path\x18\x01 \x01(\t\x12\x1a\n\x12\x66ile_size_in_bytes\x18\x02 \x01(\x04\"{\n\x13\x44\x61taFileSplitSource\x12\x34\n\x10table_identifier\x18\x01 \x01(\x0b\x32\x1a.cz.proto.ObjectIdentifier\x12.\n\x0e\x64\x61ta_file_info\x18\x02 \x03(\x0b\x32\x16.cz.proto.DataFileInfo\"\xa5\x01\n\x0fTableFormatInfo\x12\x13\n\x0bsnapshot_id\x18\x01 \x01(\x03\x12\x34\n\x07iceberg\x18\n \x01(\x0b\x32!.cz.proto.TableFormatInfo.IcebergH\x00\x1a=\n\x07Iceberg\x12\x19\n\x11metadata_location\x18\x01 \x01(\t\x12\x17\n\x0f\x63urrent_version\x18\x02 \x01(\x03\x42\x08\n\x06\x66ormat\"D\n\x0bTableFormat\x12\x35\n\x12table_format_infos\x18\x01 \x03(\x0b\x32\x19.cz.proto.TableFormatInfo\"\x99\x04\n\tTableMeta\x12\x10\n\x08table_id\x18\x01 \x01(\x03\x12\'\n\ntable_type\x18\x02 \x01(\x0e\x32\x13.cz.proto.TableType\x12+\n\x0ctable_schema\x18\x0f \x01(\x0b\x32\x15.cz.proto.TableSchema\x12)\n\x0b\x64\x61ta_source\x18\x10 \x01(\x0b\x32\x14.cz.proto.DataSource\x12-\n\x10primary_key_spec\x18\x15 \x01(\x0b\x32\x13.cz.proto.FieldSpec\x12,\n\x0fsort_order_spec\x18\x16 \x01(\x0b\x32\x13.cz.proto.FieldSpec\x12.\n\x11\x63luster_info_spec\x18\x17 \x03(\x0b\x32\x13.cz.proto.FieldSpec\x12,\n\x0funique_key_spec\x18\x18 \x03(\x0b\x32\x13.cz.proto.FieldSpec\x12\'\n\nindex_spec\x18\x1a \x03(\x0b\x32\x13.cz.proto.FieldSpec\x12-\n\x10\x66oreign_key_spec\x18\x1f \x03(\x0b\x32\x13.cz.proto.FieldSpec\x12\x1c\n\x04view\x18\x19 \x01(\x0b\x32\x0e.cz.proto.View\x12\x1b\n\x13\x63urrent_snapshot_id\x18\x1b \x01(\x03\x12+\n\x0ctable_format\x18\x1e \x01(\x0b\x32\x15.cz.proto.TableFormatB\x0c\n\x08\x63z.protoP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'table_meta_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\010cz.protoP\001'
  _globals['_TABLESCHEMALIST']._serialized_start=75
  _globals['_TABLESCHEMALIST']._serialized_end=158
  _globals['_FIELDSPECLIST']._serialized_start=160
  _globals['_FIELDSPECLIST']._serialized_end=236
  _globals['_COMPOSITEFIELDSPECLIST']._serialized_start=238
  _globals['_COMPOSITEFIELDSPECLIST']._serialized_end=331
  _globals['_DATAFILEINFO']._serialized_start=333
  _globals['_DATAFILEINFO']._serialized_end=394
  _globals['_DATAFILESPLITSOURCE']._serialized_start=396
  _globals['_DATAFILESPLITSOURCE']._serialized_end=519
  _globals['_TABLEFORMATINFO']._serialized_start=522
  _globals['_TABLEFORMATINFO']._serialized_end=687
  _globals['_TABLEFORMATINFO_ICEBERG']._serialized_start=616
  _globals['_TABLEFORMATINFO_ICEBERG']._serialized_end=677
  _globals['_TABLEFORMAT']._serialized_start=689
  _globals['_TABLEFORMAT']._serialized_end=757
  _globals['_TABLEMETA']._serialized_start=760
  _globals['_TABLEMETA']._serialized_end=1297
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: block_bloom_filter.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import hash_pb2 as hash__pb2
from . import pb_util_pb2 as pb__util__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x62lock_bloom_filter.proto\x12\x04kudu\x1a\nhash.proto\x1a\rpb_util.proto\"\xab\x01\n\x12\x42lockBloomFilterPB\x12\x17\n\x0flog_space_bytes\x18\x01 \x01(\x05\x12\x18\n\nbloom_data\x18\x02 \x01(\x0c\x42\x04\x88\xb5\x18\x01\x12\x14\n\x0c\x61lways_false\x18\x03 \x01(\x08\x12\x36\n\x0ehash_algorithm\x18\x04 \x01(\x0e\x32\x13.kudu.HashAlgorithm:\tFAST_HASH\x12\x14\n\thash_seed\x18\x05 \x01(\r:\x01\x30\x42\x11\n\x0forg.apache.kudu')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'block_bloom_filter_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017org.apache.kudu'
  _globals['_BLOCKBLOOMFILTERPB'].fields_by_name['bloom_data']._options = None
  _globals['_BLOCKBLOOMFILTERPB'].fields_by_name['bloom_data']._serialized_options = b'\210\265\030\001'
  _globals['_BLOCKBLOOMFILTERPB']._serialized_start=62
  _globals['_BLOCKBLOOMFILTERPB']._serialized_end=233
# @@protoc_insertion_point(module_scope)



import random

import sqlalchemy
from clickzetta.client import Client
from clickzetta.table import Table
from clickzetta.enums import LoginParams, QueryApiMethod
from clickzetta.dbapi.connection import Connection
from clickzetta.dbapi.cursor import Cursor
from datetime import datetime


def test_login() -> str:
    login_params = LoginParams("1", "Abc123456", "1")
    test_client = Client(login_params)
    return test_client.token


def test_select_table():
    login_params = LoginParams("1", "Abc123456", "1")
    test_client = Client(login_params)
    table = Table(1, 'default', 'regression_test', 'call_center', '1', 'cz_gp_daily')
    # select_sql = "select * from call_center;"
    # test_client.select_table(table, test_client.token, select_sql)
    test_client.show_table(table, test_client.token)


def test_connection():
    login_params = LoginParams("1", "Abc123456", "1")
    test_client = Client(login_params, '1', 'default', 'regression_test', '1', 'cz_gp_daily')
    connection = Connection(test_client)
    cursor = connection.cursor()
    cursor.execute(operation='select * from call_center;')
    print(cursor.fetchone())
    print(cursor.fetchmany(2))
    print(cursor.fetchall())
    connection.close()


def test_get_table_name_from_select():
    login_params = LoginParams("1", "Abc123456", "1")
    str_1 = '2023-02-05 13:23:44.675'
    print(str_1.replace('-', '').replace(':', '').replace('.', '').replace(' ', '') + str(random.randint(10000, 99999)))
    print((datetime(2023, 3, 20) - datetime(1970, 1, 1)).days)
    date_string = "2023-03-20"
    date_time = datetime.strptime(date_string, '%Y-%m-%d')
    print((date_time - datetime(1970, 1, 1)).days)


"""Cursor for ClickZetta DB-API."""
import abc

import collections
import logging
import contextlib
import re
from collections.abc import Mapping
from decimal import Decimal
from typing import Sequence, Union, Any, Optional, Dict, Tuple

from clickzetta.enums import JobID, FetchMode

from clickzetta.query_result import QueryResult

_LOGGER = logging.getLogger(__name__)

Column = collections.namedtuple(
    "Column",
    [
        "name",
        "type_code",
        "display_size",
        "internal_size",
        "precision",
        "scale",
        "null_ok",
    ],
)
SQL_COMMENT = r"\/\*.*?\*\/"

RE_SQL_INSERT_STMT = re.compile(
    rf"({SQL_COMMENT}|\s)*INSERT({SQL_COMMENT}|\s)"
    r"*(?:IGNORE\s+)?INTO\s+[`'\"]?.+[`'\"]?(?:\.[`'\"]?.+[`'\"]?)"
    r"{0,2}\s+VALUES\s*(\(.+\)).*",
    re.I | re.M | re.S,
    )

RE_SQL_ON_DUPLICATE = re.compile(
    r"""\s*ON\s+DUPLICATE\s+KEY(?:[^"'`]*["'`][^"'`]*["'`])*[^"'`]*$""",
    re.I | re.M | re.S,
    )

RE_SQL_COMMENT = re.compile(
    rf"""({SQL_COMMENT})|(["'`][^"'`]*?({SQL_COMMENT})[^"'`]*?["'`])""",
    re.I | re.M | re.S,
    )

RE_SQL_INSERT_VALUES = re.compile(r".*VALUES\s*(\(.+\)).*", re.I | re.M | re.S)

RE_PY_MAPPING_PARAM = re.compile(
    rb"""
    %
    \((?P<mapping_key>[^)]+)\)
    (?P<conversion_type>[diouxXeEfFgGcrs%])
    """,
    re.X,
)

class _ParamSubstitutor:
    """
    Substitutes parameters into SQL statement.
    """

    def __init__(self, params: Sequence[bytes]) -> None:
        self.params: Sequence[bytes] = params
        self.index: int = 0

    def __call__(self, matchobj: re.Match) -> bytes:
        index = self.index
        self.index += 1
        try:
            return bytes(self.params[index])
        except IndexError:
            raise Exception(
                "Not enough parameters for the SQL statement"
            ) from None

    @property
    def remaining(self) -> int:
        """Returns number of parameters remaining to be substituted"""
        return len(self.params) - self.index


class Cursor(object):
    def __init__(self, connection):
        self.connection = connection
        self.description = None
        self.arraysize = 100
        self.rowcount = -1
        self._query_result = None
        self._query_data = None
        self._closed = False
        self.job_id = None
        self._rows = None
        self.row_number = 0

    def __enter__(self):
        return self

    def __exit__(self, exc_type, exc_val, exc_tb):
        self.close()

    def close(self):
        self._closed = True

    def check_rows(self, fetch_mode=FetchMode.FETCH_ALL, size=0):
        if self._rows is None or self.row_number >= len(self._rows):
            self._rows = self._query_data.read(fetch_mode, size)
            self.row_number = 0

    def _set_rowcount(self, query_result):

        self.rowcount = query_result.total_row_count

    def _set_description(self, query_result: QueryResult):
        if query_result.schema is None:
            self.description = None
            return

        self.description = tuple(
            Column(
                name=field.name,
                type_code=field.field_type,
                display_size=None,
                internal_size=field.length,
                precision=field.precision,
                scale=field.scale,
                null_ok=field.nullable,
            )
            for field in query_result.schema
        )

    def execute(self, operation: str, parameters=None):

        self._execute(operation, parameters)

    def _execute(
            self, operation: str, parameters
    ):
        if operation is None:
            raise ValueError("sql is empty")
        else:
            operation = operation.strip()
            if operation == "":
                raise ValueError("sql is empty")
        self._query_data = None
        self._query_job = None
        client = self.connection._client
        operation = operation + ";" if not operation.endswith(";") else operation

        self.job_id = client._format_job_id()
        self.query = operation

        job_id = JobID(self.job_id, client.workspace, 100)

        self._query_result = client.submit_sql_job(token=client.token, sql=operation, job_id=job_id,
                                                   parameters=parameters)
        self._set_rowcount(self._query_result)
        self._query_data = self._query_result.data
        self._set_description(self._query_result)

    def executemany(self, operation: str):
        raise NotImplementedError

    def fetchone(self):
        self.check_rows(fetch_mode=FetchMode.FETCH_ONE)
        if self._rows is None or self.row_number >= len(self._rows):
            return None
        else:
            row = self._rows[self.row_number]
            self.row_number += 1
            return row

    def fetchmany(self, size=None):
        self.check_rows(fetch_mode=FetchMode.FETCH_MANY, size=size)
        if self._rows is None or self.row_number >= len(self._rows):
            return []
        else:
            end = self.row_number + (size or self.arraysize)
            rows = self._rows[self.row_number:end]
            self.row_number = min(end, len(self._rows))
            return rows

    def fetchall(self):
        self.check_rows(fetch_mode=FetchMode.FETCH_ALL)
        if self._rows is None or self.row_number >= len(self._rows):
            return []
        else:
            rows = self._rows[self.row_number:]
            self.row_number = len(self._rows)
            return rows

    def fetch_panda_all(self):
        return self._query_result.panda_data

    def get_job_id(self):
        return self.job_id

    def setinputsizes(self, sizes):
        """No-op, but for consistency raise an error if cursor is closed."""

    def setoutputsize(self, size, column=None):
        """No-op, but for consistency raise an error if cursor is closed."""

    def __iter__(self):
        return iter(self._query_data)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: virtual_cluster_size.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1avirtual_cluster_size.proto\x12\x11\x63om.clickzetta.rm\"\xba\x01\n\x16VirtualClusterSizeSpec\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x07\x61lias_1\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07\x61lias_2\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07\x61lias_3\x18\x05 \x01(\tH\x02\x88\x01\x01\x12\x10\n\x08\x63pu_core\x18\x06 \x01(\x01\x12\x0e\n\x06mem_gb\x18\x07 \x01(\x03\x42\n\n\x08_alias_1B\n\n\x08_alias_2B\n\n\x08_alias_3b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'virtual_cluster_size_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_VIRTUALCLUSTERSIZESPEC']._serialized_start=50
  _globals['_VIRTUALCLUSTERSIZESPEC']._serialized_end=236
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: input_split.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import virtual_value_info_pb2 as virtual__value__info__pb2
from . import statistics_pb2 as statistics__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11input_split.proto\x12\x08\x63z.proto\x1a\x18virtual_value_info.proto\x1a\x10statistics.proto\"\xc1\x01\n\nInputSplit\x12&\n\x04type\x18\x01 \x01(\x0e\x32\x18.cz.proto.InputSplitType\x12\x12\n\noperatorId\x18\x02 \x01(\t\x12\x34\n\nfileRanges\x18\x03 \x01(\x0b\x32\x1e.cz.proto.FileRangesInputSplitH\x00\x12\x38\n\x0c\x66ileRowRange\x18\x04 \x01(\x0b\x32 .cz.proto.FileRowRangeInputSplitH\x00\x42\x07\n\x05split\"<\n\x0e\x46ileFieldStats\x12*\n\x0c\x66ield_ranges\x18\x01 \x03(\x0b\x32\x14.cz.proto.FieldRange\"\xe7\x01\n\tFileRange\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x03\x12\x0c\n\x04size\x18\x03 \x01(\x03\x12.\n\nvalue_info\x18\x04 \x01(\x0b\x32\x1a.cz.proto.VirtualValueInfo\x12(\n\x0b\x64\x65lta_files\x18\x05 \x03(\x0b\x32\x13.cz.proto.FileRange\x12%\n\x04type\x18\x06 \x01(\x0e\x32\x17.cz.proto.FileRangeType\x12-\n\x0b\x66ield_stats\x18\x07 \x01(\x0b\x32\x18.cz.proto.FileFieldStats\"d\n\x14\x46ileRangesInputSplit\x12#\n\x06ranges\x18\x02 \x03(\x0b\x32\x13.cz.proto.FileRange\x12\x14\n\x0c\x62ucket_count\x18\x03 \x01(\r\x12\x11\n\tbucket_id\x18\x04 \x01(\r\"J\n\x16\x46ileRowRangeInputSplit\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\tstart_row\x18\x02 \x01(\x03\x12\x0f\n\x07\x65nd_row\x18\x03 \x01(\x03\"\x95\x01\n\tRangeFile\x12\x11\n\x04path\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\trecordCnt\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x15\n\x08\x66ileSize\x18\x03 \x01(\x03H\x02\x88\x01\x01\x12\x15\n\x08location\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x07\n\x05_pathB\x0c\n\n_recordCntB\x0b\n\t_fileSizeB\x0b\n\t_location\"K\n\x0cRangeLiteral\x12\x0e\n\x04intV\x18\x01 \x01(\x05H\x00\x12\x0f\n\x05longV\x18\x02 \x01(\x03H\x00\x12\x11\n\x07stringV\x18\x03 \x01(\tH\x00\x42\x07\n\x05value\"\xa9\x01\n\x0eRangePartition\x12\x14\n\x07rangeId\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\'\n\nrangeFiles\x18\x02 \x03(\x0b\x32\x13.cz.proto.RangeFile\x12%\n\x05lower\x18\x03 \x03(\x0b\x32\x16.cz.proto.RangeLiteral\x12%\n\x05upper\x18\x04 \x03(\x0b\x32\x16.cz.proto.RangeLiteralB\n\n\x08_rangeId\"#\n\x0fOutputSplitType\"\x10\n\x04Type\x12\x08\n\x04\x46ILE\x10\x00\"\x83\x01\n\x0bOutputSplit\x12,\n\x04type\x18\x01 \x01(\x0e\x32\x1e.cz.proto.OutputSplitType.Type\x12\x12\n\noperatorId\x18\x02 \x01(\t\x12)\n\x04\x66ile\x18\x04 \x01(\x0b\x32\x19.cz.proto.FileOutputSplitH\x00\x42\x07\n\x05split\"\x1f\n\x0f\x46ileOutputSplit\x12\x0c\n\x04path\x18\x01 \x01(\t\"\x98\x01\n\rFileSplitMeta\x12\x12\n\nsplit_file\x18\x03 \x01(\t\x12.\n\x06offset\x18\x04 \x03(\x0b\x32\x1e.cz.proto.FileSplitMeta.Offset\x1a\x43\n\x06Offset\x12\x0f\n\x07task_id\x18\x01 \x01(\x03\x12\x14\n\x0cstart_offset\x18\x02 \x01(\x03\x12\x12\n\nend_offset\x18\x03 \x01(\x03\"\xb0\x01\n\x11\x45mbeddedSplitMeta\x12\x30\n\x06splits\x18\x03 \x03(\x0b\x32 .cz.proto.EmbeddedSplitMeta.Pair\x1ai\n\x04Pair\x12\x0f\n\x07task_id\x18\x01 \x01(\x03\x12#\n\x05split\x18\x02 \x01(\x0b\x32\x14.cz.proto.InputSplit\x12+\n\x0coutput_split\x18\x03 \x01(\x0b\x32\x15.cz.proto.OutputSplit\"\x97\x01\n\tSplitMeta\x12\x10\n\x08stage_id\x18\x01 \x01(\t\x12\x13\n\x0boperator_id\x18\x02 \x01(\t\x12\'\n\x04\x66ile\x18\x03 \x01(\x0b\x32\x17.cz.proto.FileSplitMetaH\x00\x12/\n\x08\x65mbedded\x18\x04 \x01(\x0b\x32\x1b.cz.proto.EmbeddedSplitMetaH\x00\x42\t\n\x07\x63ontent\"\xb6\x01\n\x13\x43ompactionSplitFile\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x03\x12\x0c\n\x04size\x18\x03 \x01(\x03\x12\x0f\n\x07sliceId\x18\x04 \x01(\x03\x12.\n\nvalue_info\x18\x05 \x01(\x0b\x32\x1a.cz.proto.VirtualValueInfo\x12\x32\n\x0b\x64\x65lta_files\x18\x06 \x03(\x0b\x32\x1d.cz.proto.CompactionSplitFile\"?\n\x0f\x43ompactionSplit\x12,\n\x05\x66iles\x18\x01 \x03(\x0b\x32\x1d.cz.proto.CompactionSplitFile\"=\n\x10\x43ompactionSplits\x12)\n\x06splits\x18\x01 \x03(\x0b\x32\x19.cz.proto.CompactionSplit*/\n\x0eInputSplitType\x12\x0e\n\nFILE_RANGE\x10\x00\x12\r\n\tROW_RANGE\x10\x01*B\n\rFileRangeType\x12\x0f\n\x0bNORMAL_FILE\x10\x00\x12\x0e\n\nADDED_FILE\x10\x01\x12\x10\n\x0c\x44\x45LETED_FILE\x10\x02\x42\x13\x42\x0fInputSplitProtoP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'input_split_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'B\017InputSplitProtoP\001'
  _globals['_INPUTSPLITTYPE']._serialized_start=2151
  _globals['_INPUTSPLITTYPE']._serialized_end=2198
  _globals['_FILERANGETYPE']._serialized_start=2200
  _globals['_FILERANGETYPE']._serialized_end=2266
  _globals['_INPUTSPLIT']._serialized_start=76
  _globals['_INPUTSPLIT']._serialized_end=269
  _globals['_FILEFIELDSTATS']._serialized_start=271
  _globals['_FILEFIELDSTATS']._serialized_end=331
  _globals['_FILERANGE']._serialized_start=334
  _globals['_FILERANGE']._serialized_end=565
  _globals['_FILERANGESINPUTSPLIT']._serialized_start=567
  _globals['_FILERANGESINPUTSPLIT']._serialized_end=667
  _globals['_FILEROWRANGEINPUTSPLIT']._serialized_start=669
  _globals['_FILEROWRANGEINPUTSPLIT']._serialized_end=743
  _globals['_RANGEFILE']._serialized_start=746
  _globals['_RANGEFILE']._serialized_end=895
  _globals['_RANGELITERAL']._serialized_start=897
  _globals['_RANGELITERAL']._serialized_end=972
  _globals['_RANGEPARTITION']._serialized_start=975
  _globals['_RANGEPARTITION']._serialized_end=1144
  _globals['_OUTPUTSPLITTYPE']._serialized_start=1146
  _globals['_OUTPUTSPLITTYPE']._serialized_end=1181
  _globals['_OUTPUTSPLITTYPE_TYPE']._serialized_start=1165
  _globals['_OUTPUTSPLITTYPE_TYPE']._serialized_end=1181
  _globals['_OUTPUTSPLIT']._serialized_start=1184
  _globals['_OUTPUTSPLIT']._serialized_end=1315
  _globals['_FILEOUTPUTSPLIT']._serialized_start=1317
  _globals['_FILEOUTPUTSPLIT']._serialized_end=1348
  _globals['_FILESPLITMETA']._serialized_start=1351
  _globals['_FILESPLITMETA']._serialized_end=1503
  _globals['_FILESPLITMETA_OFFSET']._serialized_start=1436
  _globals['_FILESPLITMETA_OFFSET']._serialized_end=1503
  _globals['_EMBEDDEDSPLITMETA']._serialized_start=1506
  _globals['_EMBEDDEDSPLITMETA']._serialized_end=1682
  _globals['_EMBEDDEDSPLITMETA_PAIR']._serialized_start=1577
  _globals['_EMBEDDEDSPLITMETA_PAIR']._serialized_end=1682
  _globals['_SPLITMETA']._serialized_start=1685
  _globals['_SPLITMETA']._serialized_end=1836
  _globals['_COMPACTIONSPLITFILE']._serialized_start=1839
  _globals['_COMPACTIONSPLITFILE']._serialized_end=2021
  _globals['_COMPACTIONSPLIT']._serialized_start=2023
  _globals['_COMPACTIONSPLIT']._serialized_end=2086
  _globals['_COMPACTIONSPLITS']._serialized_start=2088
  _globals['_COMPACTIONSPLITS']._serialized_end=2149
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: file_meta_data.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import bucket_info_pb2 as bucket__info__pb2
from . import file_format_type_pb2 as file__format__type__pb2
from . import statistics_pb2 as statistics__pb2
from . import virtual_value_info_pb2 as virtual__value__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x66ile_meta_data.proto\x12\x08\x63z.proto\x1a\x11\x62ucket_info.proto\x1a\x16\x66ile_format_type.proto\x1a\x10statistics.proto\x1a\x18virtual_value_info.proto\"+\n\tBlockInfo\x12\x0e\n\x06offset\x18\x01 \x01(\x04\x12\x0e\n\x06length\x18\x02 \x01(\x04\"\xfb\x01\n\nDataLayout\x12#\n\x06\x66ooter\x18\x01 \x01(\x0b\x32\x13.cz.proto.BlockInfo\x12#\n\x06\x62locks\x18\x02 \x03(\x0b\x32\x13.cz.proto.BlockInfo\x12%\n\x07\x62uckets\x18\x03 \x03(\x0b\x32\x14.cz.proto.BucketInfo\x12.\n\nvalue_info\x18\x04 \x03(\x0b\x32\x1a.cz.proto.VirtualValueInfo\x12\x1d\n\x10row_index_stride\x18\x05 \x01(\x05H\x00\x88\x01\x01\x12\x18\n\x10\x62lock_row_counts\x18\x06 \x03(\x03\x42\x13\n\x11_row_index_stride\"\x80\x01\n\x10\x45xtendedMetaData\x12;\n\tkey_value\x18\x01 \x03(\x0b\x32(.cz.proto.ExtendedMetaData.KeyValueEntry\x1a/\n\rKeyValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe9\x03\n\x0c\x46ileMetaData\x12\x11\n\tfile_path\x18\x01 \x01(\t\x12-\n\x0b\x66ile_format\x18\x02 \x01(\x0e\x32\x18.cz.proto.FileFormatType\x12%\n\tfile_type\x18\x03 \x01(\x0e\x32\x12.cz.proto.FileType\x12\x15\n\rfile_slice_id\x18\x04 \x01(\x03\x12\x1a\n\x12\x66ile_slice_version\x18\x05 \x01(\x03\x12\x18\n\x10\x63ompaction_level\x18\x06 \x01(\x05\x12\x1c\n\x0f\x63luster_spec_id\x18\x07 \x01(\rH\x00\x88\x01\x01\x12\x1f\n\x12sort_order_spec_id\x18\x08 \x01(\rH\x01\x88\x01\x01\x12 \n\x13primary_key_spec_id\x18\t \x01(\rH\x02\x88\x01\x01\x12$\n\x06layout\x18\n \x01(\x0b\x32\x14.cz.proto.DataLayout\x12\x35\n\x11\x65xtended_metadata\x18\x0b \x01(\x0b\x32\x1a.cz.proto.ExtendedMetaData\x12\"\n\x05stats\x18\x10 \x01(\x0b\x32\x13.cz.proto.StatsDataB\x12\n\x10_cluster_spec_idB\x15\n\x13_sort_order_spec_idB\x16\n\x14_primary_key_spec_id*;\n\x08\x46ileType\x12\x10\n\x0cUNKNOWN_FILE\x10\x00\x12\r\n\tDATA_FILE\x10\x01\x12\x0e\n\nDELTA_FILE\x10\x02\x42\x1f\n\x08\x63z.protoB\x11\x46ileMetaDataProtoP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'file_meta_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\010cz.protoB\021FileMetaDataProtoP\001'
  _globals['_EXTENDEDMETADATA_KEYVALUEENTRY']._options = None
  _globals['_EXTENDEDMETADATA_KEYVALUEENTRY']._serialized_options = b'8\001'
  _globals['_FILETYPE']._serialized_start=1043
  _globals['_FILETYPE']._serialized_end=1102
  _globals['_BLOCKINFO']._serialized_start=121
  _globals['_BLOCKINFO']._serialized_end=164
  _globals['_DATALAYOUT']._serialized_start=167
  _globals['_DATALAYOUT']._serialized_end=418
  _globals['_EXTENDEDMETADATA']._serialized_start=421
  _globals['_EXTENDEDMETADATA']._serialized_end=549
  _globals['_EXTENDEDMETADATA_KEYVALUEENTRY']._serialized_start=502
  _globals['_EXTENDEDMETADATA_KEYVALUEENTRY']._serialized_end=549
  _globals['_FILEMETADATA']._serialized_start=552
  _globals['_FILEMETADATA']._serialized_end=1041
# @@protoc_insertion_point(module_scope)



import random
import re
import unittest
from decimal import Decimal

import pandas
import sqlalchemy
import sqlparse
from clickzetta import connect, Client
from clickzetta.dbapi import Connection
from clickzetta.session import Session
from clickzetta.proto.generated import ingestion_pb2
from clickzetta.bulkload.bulkload_enums import *
import pytest
from pyarrow import fs
from google.protobuf.json_format import MessageToJson, MessageToDict, Parse, ParseDict
from sqlalchemy import text


class TestBulkLoad(unittest.TestCase):

    def test_bulkload_config(self):
        writer_config = ingestion_pb2.BulkloadStreamWriterConfig()
        writer_config.max_num_rows_per_file = 100
        writer_config.max_size_in_bytes_per_file = 200
        mgs_dict = MessageToDict(writer_config)
        protobuf_msg = ParseDict(mgs_dict, ingestion_pb2.BulkloadStreamWriterConfig())
        print(protobuf_msg.max_num_rows_per_file)

    def test_bulkload_simplified_interface(self):
        conn = connect(username='cz_lh_smoke_test', password='Abc123456',
                       service='dev-api.zettadecision.com', instance='clickzetta',
                       workspace='system_smoke', vcluster='cz_gp_daily')
        bulkload_stream = conn.create_bulkload_stream(schema='lakehouse_daily', table='append_cluster_python')
        writer = bulkload_stream.open_writer(0)
        row = writer.create_row()
        row.set_value('id', 1)
        row.set_value('month', 'January')
        row.set_value('amount', 45)
        row.set_value('cost', 113.56)
        writer.write(row)
        writer.close()
        bulkload_stream.commit()
        bulkload_stream.close()

    def test_get_bulkload_stream(self):
        conn = connect(username='cz_lh_smoke_test', password='Abc123456',
                       service='dev-api.zettadecision.com', instance='clickzetta',
                       workspace='system_smoke', vcluster='cz_gp_daily')
        stream1 = conn.create_bulkload_stream(schema='lakehouse_daily', table='append_cluster_python',
                                              operation=BulkLoadOperation.OVERWRITE)
        stream2 = conn.get_bulkload_stream(schema='lakehouse_daily', table='append_cluster_python',
                                           stream_id=stream1.get_stream_id())
        self.assertEqual(stream1.get_stream_id(), stream2.get_stream_id())

        writer1 = stream1.open_writer(1)
        row = writer1.create_row()
        row.set_value('id', 1)
        row.set_value('month', 'January')
        row.set_value('amount', 45)
        row.set_value('cost', 113.56)
        writer1.write(row)
        writer1.close()

        writer2 = stream2.open_writer(2)
        row = writer2.create_row()
        row.set_value('id', 2)
        row.set_value('month', 'Feb')
        row.set_value('amount', 67)
        row.set_value('cost', 561.13)
        writer2.write(row)
        writer2.close()

        stream1.commit()
        cur = conn.cursor()
        cur.execute('select id,month,amount,cost from lakehouse_daily.append_cluster_python order by id asc;')
        rs = cur.fetchall()
        cur.close()
        self.assertEqual(len(rs), 2)
        self.assertEqual(rs[0], (1, 'January', 45, Decimal('113.56')))
        self.assertEqual(rs[1], (2, 'Feb', 67, Decimal('561.13')))

    def test_bulkload_minor_writer(self):
        config = {
            'url': 'clickzetta://cz_lh_smoke_test:Abc123456@clickzetta.dev-api.zettadecision.com/system_smoke?virtualcluster=cz_gp_daily'}
        session = Session.builder.configs(config).create()
        bulkload_config = BulkLoadOptions(BulkLoadOperation.APPEND, None, None)
        bulkload_stream = session.create_bulkload_stream('lakehouse_daily', 'append_cluster_python', bulkload_config)
        writer = bulkload_stream.open_writer(0)

        row = writer.create_row()
        row.set_value('id', 1)
        row.set_value('month', 'January')
        row.set_value('amount', 45)
        row.set_value('cost', 113.56)
        writer.write(row)

        writer.close()
        commit_options = BulkLoadCommitOptions('system_smoke', 'cz_gp_daily')
        bulkload_stream.commit(commit_options)
        bulkload_stream.close()
        session.close()

    def test_bulkload_major_writer(self):
        config = {
            'url': 'clickzetta://cz_lh_smoke_test:Abc123456@clickzetta.dev-api.zettadecision.com/system_smoke?virtualcluster=cz_gp_daily'}
        session = Session.builder.configs(config).create()
        bulkload_config = BulkLoadOptions(BulkLoadOperation.APPEND, None, None)
        bulkload_stream = session.create_bulkload_stream('lakehouse_daily', 'append_cluster_python', bulkload_config)
        writer = bulkload_stream.open_writer(0)

        for index in range(1, 6000000):
            row = writer.create_row()
            row.set_value('id', index)
            row.set_value('month', 'January')
            row.set_value('amount', 45)
            row.set_value('cost', 113.56)
            writer.write(row)

        writer.close()
        commit_options = BulkLoadCommitOptions('system_smoke', 'cz_gp_daily')
        bulkload_stream.commit(commit_options)
        bulkload_stream.close()
        session.close()

    def test_bulkload_distributed_writer(self):
        config = {
            'url': 'clickzetta://cz_lh_smoke_test:Abc123456@clickzetta.dev-api.zettadecision.com/system_smoke?virtualcluster=cz_gp_daily'}
        session = Session.builder.configs(config).create()
        bulkload_config = BulkLoadOptions(BulkLoadOperation.APPEND, None, None)
        driver_bulkload_stream = session.create_bulkload_stream('lakehouse_daily', 'append_cluster_python',
                                                                bulkload_config)
        stream_id = driver_bulkload_stream.get_stream_id()
        executor_stream = session.get_bulkload_stream('lakehouse_daily', 'append_cluster_python', stream_id)
        writer_list = []
        for index in range(3):
            writer_list.append(executor_stream.open_writer(index))

        for writer in writer_list:
            row = writer.create_row()
            row.set_value('id', random.randint(1, 1000))
            row.set_value('month', 'January')
            row.set_value('amount', 45)
            row.set_value('cost', 113.56)
            writer.write(row)

        for writer in writer_list:
            writer.close()
        executor_stream.close()
        commit_options = BulkLoadCommitOptions('system_smoke', 'cz_gp_daily')
        driver_bulkload_stream.commit(commit_options)
        driver_bulkload_stream.close()
        session.close()

    def test_bulkload_major_overwriter(self):
        config = {
            'url': 'clickzetta://cz_lh_smoke_test:Abc123456@clickzetta.dev-api.zettadecision.com/system_smoke?virtualcluster=cz_gp_daily'}
        session = Session.builder.configs(config).create()
        bulkload_config = BulkLoadOptions(BulkLoadOperation.OVERWRITE, None, None)
        bulkload_stream = session.create_bulkload_stream('lakehouse_daily', 'append_cluster_python', bulkload_config)
        writer = bulkload_stream.open_writer(0)

        for index in range(1, 1000000):
            row = writer.create_row()
            row.set_value('id', index + 1)
            row.set_value('month', 'January')
            row.set_value('amount', 45)
            row.set_value('cost', 113.56)
            writer.write(row)

        writer.close()
        commit_options = BulkLoadCommitOptions('system_smoke', 'cz_gp_daily')
        bulkload_stream.commit(commit_options)
        bulkload_stream.close()
        session.close()

    def test_bulkload_major_upsert_writer(self):
        config = {
            'url': 'clickzetta://cz_lh_smoke_test:Abc123456@clickzetta.dev-api.zettadecision.com/system_smoke?virtualcluster=cz_gp_daily'}
        session = Session.builder.configs(config).create()
        bulkload_config = BulkLoadOptions(BulkLoadOperation.UPSERT, None, ['id'])
        bulkload_stream = session.create_bulkload_stream('lakehouse_daily', 'append_cluster_python', bulkload_config)
        writer = bulkload_stream.open_writer(0)

        for index in range(1, 1000000):
            row = writer.create_row()
            row.set_value('id', index + 1)
            row.set_value('month', 'January')
            row.set_value('amount', 45)
            row.set_value('cost', 113.56)
            writer.write(row)

        writer.close()
        commit_options = BulkLoadCommitOptions('system_smoke', 'cz_gp_daily')
        bulkload_stream.commit(commit_options)
        bulkload_stream.close()
        session.close()

    def test_bulkload_major_append_pt_writer(self):
        config = {
            'url': 'clickzetta://cz_lh_smoke_test:Abc123456@clickzetta.dev-api.zettadecision.com/system_smoke?virtualcluster=cz_gp_daily'}
        session = Session.builder.configs(config).create()
        bulkload_config = BulkLoadOptions(BulkLoadOperation.APPEND, "pt=python_bulkload", None)
        bulkload_stream = session.create_bulkload_stream('lakehouse_daily', 'upsert_cluster_pt_python', bulkload_config)
        writer = bulkload_stream.open_writer(0)

        for index in range(1, 1000000):
            row = writer.create_row()
            row.set_value('id', index + 1)
            row.set_value('month', 'January')
            row.set_value('amount', 45)
            row.set_value('cost', 113.56)
            writer.write(row)

        writer.close()
        commit_options = BulkLoadCommitOptions('system_smoke', 'cz_gp_daily')
        bulkload_stream.commit(commit_options)
        bulkload_stream.close()
        session.close()

    def test_bulkload_major_pt_overwriter(self):
        config = {
            'url': 'clickzetta://cz_lh_smoke_test:Abc123456@clickzetta.dev-api.zettadecision.com/system_smoke?virtualcluster=cz_gp_daily'}
        session = Session.builder.configs(config).create()
        bulkload_config = BulkLoadOptions(BulkLoadOperation.OVERWRITE, "pt=python_bulkload", None)
        bulkload_stream = session.create_bulkload_stream('lakehouse_daily', 'upsert_cluster_pt_python', bulkload_config)
        writer = bulkload_stream.open_writer(0)

        for index in range(1, 3000000):
            row = writer.create_row()
            row.set_value('id', index + 1)
            row.set_value('month', 'January')
            row.set_value('amount', 45)
            row.set_value('cost', 113.56)
            writer.write(row)

        writer.close()
        commit_options = BulkLoadCommitOptions('system_smoke', 'cz_gp_daily')
        bulkload_stream.commit(commit_options)
        bulkload_stream.close()
        session.close()

    def test_bulkload_major_upsert_pt_writer(self):
        config = {
            'url': 'clickzetta://cz_lh_smoke_test:Abc123456@clickzetta.dev-api.zettadecision.com/system_smoke?virtualcluster=cz_gp_daily'}
        session = Session.builder.configs(config).create()
        bulkload_config = BulkLoadOptions(BulkLoadOperation.UPSERT, "pt=python_bulkload", ['id'])
        bulkload_stream = session.create_bulkload_stream('lakehouse_daily', 'upsert_cluster_pt_python', bulkload_config)
        writer = bulkload_stream.open_writer(0)

        for index in range(1, 1000000):
            row = writer.create_row()
            row.set_value('id', index + 1)
            row.set_value('month', 'January')
            row.set_value('amount', 45)
            row.set_value('cost', 113.56)
            writer.write(row)

        writer.close()
        commit_options = BulkLoadCommitOptions('system_smoke', 'cz_gp_daily')
        bulkload_stream.commit(commit_options)
        bulkload_stream.close()
        session.close()

    def test_ut_2(self):
        config = {
            'url': 'clickzetta://on_lh_test:Abc123456@6f5afa19.dev-api.clickzetta.com/qa_smoke_test?virtualcluster=default'}
        session = Session.builder.configs(config).create()
        bulkload_config = BulkLoadOptions(BulkLoadOperation.APPEND, None, None)
        bulkload_stream = session.create_bulkload_stream('PUBLIC', 'lh_smoke_test_python_sdk_bulkload', bulkload_config)
        writer = bulkload_stream.open_writer(0)

        for index in range(1, 6000000):
            row = writer.create_row()
            row.set_value('col1', index)
            row.set_value('col2', str(index))
            writer.write(row)

        writer.close()
        commit_options = BulkLoadCommitOptions('qa_smoke_test', 'DEFAULT')
        bulkload_stream.commit(commit_options)
        bulkload_stream.close()
        session.close()

    def test_ut_3(self):
        from clickzetta.client import Client
        from clickzetta.dbapi.connection import Connection
        client = Client(
            cz_url="clickzetta://SD_demo:Asddemo123@6861c888.api.clickzetta.com/quickStart_WS?virtualCluster=default")
        conn = Connection(client)

        cursor = conn.cursor()
        sql = "select * from clickzetta_sample_data.ecommerce_events_history.ecommerce_events_multicategorystore_live limit 20000;"
        cursor.execute(sql)
        results = cursor.fetchone()
        count = 0
        print(results)
        for r in results:
            count += 1
            print(count)
            print(r)

    def test_huge_result_case(self):
        from sqlalchemy import create_engine
        from sqlalchemy import text

        engine = create_engine(
            "clickzetta://SD_demo:Asddemo123!@6861c888.api.clickzetta.com/quickStart_WS?virtualCluster=default")

        sql = text(
            "select * from clickzetta_sample_data.ecommerce_events_history.ecommerce_events_multicategorystore_live limit 100000;")

        count = 0
        with engine.connect() as conn:
            cursor = conn.execute(sql)
            results = cursor.fetchall()
            for r in results:
                count += 1
                print(count)
                print(r)

    def test_query_with_magic_token(self):
        from sqlalchemy import create_engine
        from sqlalchemy import text
        engine = create_engine(
            "clickzetta://:@6861c888.api.clickzetta.com/quickStart_WS?virtualCluster=default&magic_token=eyJhbGciOiJIUzI1Ni.eyJhY2NvdW50SWQiOjExMTAxMSwidGVuYW50SWQiOjExMTAxMSwidXNlck5hbWUiOiJTRF9kZW1vIiwidXNlcklkIjoxMDA4MTQ5LCJpYXQiOjE2OTI4NjAyMDMsImV4cCI6MTY5MzExOTQwM30.HP7JN8QLyPOLF3gs_tmEmGQtmd0yTo77h2TIPEc0ZwA&schema=ecommerce_events_history")

        sql = text(
            "select * from clickzetta_sample_data.ecommerce_events_history.ecommerce_events_multicategorystore_live limit 1000;")

        count = 0
        with engine.connect() as conn:
            results = conn.execute(sql).fetchall()
            for r in results:
                count += 1
                print(count)
                print(r)

    def test_get_job_profile(self):
        from clickzetta.client import Client
        from clickzetta.dbapi.connection import Connection
        client = Client(
            cz_url="clickzetta://SD_demo:Asddemo123!@6861c888.api.clickzetta.com/quickStart_WS?virtualCluster=default")
        conn = Connection(client)

        cursor = conn.cursor()
        sql = "select * from clickzetta_sample_data.ecommerce_events_history.ecommerce_events_multicategorystore_live limit 10000;"
        cursor.execute(sql)
        results = cursor.fetchall()
        count = 0
        print(results)
        for r in results:
            count += 1
            print(count)
            print(r)
        print(conn.get_job_profile(cursor.job_id))

    def test_url_protocol(self):
        from sqlalchemy import create_engine
        from sqlalchemy import text

        engine = create_engine(
            "clickzetta://SD_demo:Asddemo123!@6861c888.api.clickzetta.com/quickStart_WS?virtualCluster=default&protocol=http")

        sql = text(
            "select * from clickzetta_sample_data.ecommerce_events_history.ecommerce_events_multicategorystore_live limit 1000;")

        count = 0
        with engine.connect() as conn:
            cursor = conn.execute(sql)
            results = cursor.fetchall()
            for r in results:
                count += 1
                print(count)
                print(r)

    def test_sdk_timeout(self):
        conn = connect(username='xxx', password='xxx',instance='xxx', service='api.clickzetta.com', workspace='syntax_space', schema='public', vcluster='SYNTAX_AP')
        hints = {
            "cz.sql.group.by.having.use.alias.first": "true",
            "cz.top.down.pass.through": "false",
            "cz.bottom.up.pass.through": "false",
            "cz.optimizer.post.process.join.column.prune": "true",
            "cz.sql.playback.scratch": "true",
            "cz.optimizer.enable.agg.push.down": "false",
            "sdk.job.timeout": "10"
        }
        parmas = {'hints': hints}
        cursor = conn.cursor()
        cursor.execute("select count(*) from validation_query_result_db.validation_query_result_table_20230920150841409405", parameters=parmas)
        results = cursor.fetchall()
        for result in results:
            print(result)

    def test_repeat_column_names(self):
        from sqlalchemy import create_engine
        from sqlalchemy import text

        engine = create_engine(
            "clickzetta://SD_demo:Asddemo123!@6861c888.api.clickzetta.com/quickStart_WS?virtualCluster=default&protocol=http")

        sql = text(
            "SELECT DATE_FORMAT(NOW(),'HH:mm:ss'), DATE_FORMAT(NOW(),'HH:mm:ss'), DATE_FORMAT(NOW(),'HH:mm:ss');")

        with engine.connect() as conn:
            cursor = conn.execute(sql)
            results = cursor.fetchall()
            for r in results:
                print(r)

    def test_get_volume(self):
        from clickzetta.client import Client
        from clickzetta.dbapi.connection import Connection
        client = Client(
            cz_url="clickzetta://system_admin:Abc123456@clickzetta.dev-api.zettadecision.com/default?virtualcluster=cz_gp_daily&schema=copy_test")
        conn = Connection(client)

        cursor = conn.cursor()
        sql = "show volume directory vol_test_092616;"
        cursor.execute(sql)
        results = cursor.fetchall()
        for r in results:
            print(r)
        get_volume_sql = 'get volume vol_test_092616/1/2.txt to /tmp/5.txt;'
        cursor.execute(get_volume_sql)
        result = cursor.fetchall()
        print(result)

    def test_put_volume(self):
        from clickzetta.client import Client
        from clickzetta.dbapi.connection import Connection
        client = Client(
            cz_url="clickzetta://system_admin:Abc123456@clickzetta.dev-api.zettadecision.com/default?virtualcluster=cz_gp_daily&schema=copy_test")
        conn = Connection(client)

        cursor = conn.cursor()

        get_volume_sql = 'put /tmp/3.txt to volume vol_test_092616/1/25.txt;'
        cursor.execute(get_volume_sql)
        result = cursor.fetchall()
        print(result)
        sql = "show volume directory vol_test_092616;"
        cursor.execute(sql)
        results = cursor.fetchall()
        for r in results:
            print(r)

    def test_repeat_column_names_1(self):
        from sqlalchemy import create_engine
        from sqlalchemy import text

        engine = create_engine(
            "clickzetta://atlas:Aatlas12345@809b4f0a.ap-southeast-1-alicloud.api.clickzetta.com/quickstart_ws?virtualCluster=ANALYSIS")

        sql = text(
            "select * from atlas_dwd.dwd_search_t_search_log_h_inc limit 10")

        with engine.connect() as conn:
            cursor = conn.execute(sql)
            results = cursor.fetchall()
            for r in results:
                print(r)
    def test_multi_result_files(self):
        from clickzetta.client import Client
        from clickzetta.dbapi.connection import connect
        conn = connect(cz_url="")
        cursor = conn.cursor()
        cursor.get_job_id()
        client = Client(
            cz_url="clickzetta://yunqi:Amedia_track12@ac5079d2.ap-shanghai-tencentcloud.api.clickzetta.com/media_track?virtualcluster=MEDIATRACK_AP&schema=realtime")
        conn = Connection(client)

        cursor = conn.cursor()
        sql = "select distinct `database_name`, `schema_name`, `table_name` from realtime.cdc_events where `emitted_at`>=1702635844470 and `emitted_at`<=1702635875947;"
        cursor.execute(sql)
        results = cursor.fetchall()
        print(len(results))
        for r in results:
            print(r)


import openai
import json


def test_openai_1():
    openai.api_key = ''

    q = "用python实现冒泡算法"
    rsp = openai.ChatCompletion.create(
        model="gpt-3.5-turbo",
        messages=[
            {"role": "user", "content": q}
        ]
    )
    print(rsp.get("choices")[0]["message"]["content"])



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: job_meta.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0ejob_meta.proto\x12\x08\x63z.proto\"&\n\x07JobCost\x12\x0b\n\x03\x63pu\x18\x01 \x01(\r\x12\x0e\n\x06memory\x18\x02 \x01(\r\"s\n\nJobHistory\x12\x18\n\x10\x63oordinator_host\x18\x01 \x01(\t\x12\x1b\n\x13\x63oordinator_version\x18\x02 \x01(\x04\x12\x15\n\rstart_time_ms\x18\x03 \x01(\x04\x12\x17\n\x0frelease_version\x18\x04 \x01(\t\"\xaf\x01\n\x0cSQLJobConfig\x12\x0f\n\x07timeout\x18\x01 \x01(\x05\x12\x18\n\x10\x61\x64hoc_size_limit\x18\x02 \x01(\x03\x12\x17\n\x0f\x61\x64hoc_row_limit\x18\x03 \x01(\x03\x12.\n\x04hint\x18\x04 \x03(\x0b\x32 .cz.proto.SQLJobConfig.HintEntry\x1a+\n\tHintEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"{\n\x06SQLJob\x12\r\n\x05query\x18\x01 \x03(\t\x12\x19\n\x11\x64\x65\x66\x61ult_namespace\x18\x02 \x03(\t\x12*\n\nsql_config\x18\x03 \x01(\x0b\x32\x16.cz.proto.SQLJobConfig\x12\x1b\n\x13\x64\x65\x66\x61ult_instance_id\x18\x04 \x01(\x03\"x\n\x12JobSummaryLocation\x12\x18\n\x10summary_location\x18\x01 \x01(\t\x12\x15\n\rplan_location\x18\x02 \x01(\t\x12\x16\n\x0estats_location\x18\x03 \x01(\t\x12\x19\n\x11progress_location\x18\x04 \x01(\t\"\x8b\x08\n\x07JobMeta\x12\x10\n\x08job_name\x18\x02 \x01(\t\x12\x17\n\x0fvirtual_cluster\x18\x03 \x01(\x03\x12#\n\x06status\x18\x04 \x01(\x0e\x32\x13.cz.proto.JobStatus\x12\x1f\n\x04type\x18\x05 \x01(\x0e\x32\x11.cz.proto.JobType\x12\x12\n\nstart_time\x18\x06 \x01(\x04\x12\x10\n\x08\x65nd_time\x18\x07 \x01(\x04\x12\x10\n\x08priority\x18\t \x01(\r\x12\x11\n\tsignature\x18\n \x01(\t\x12\x1f\n\x04\x63ost\x18\x0b \x01(\x0b\x32\x11.cz.proto.JobCost\x12\x30\n\thistories\x18\x0c \x01(\x0b\x32\x1d.cz.proto.JobMeta.HistoryList\x12\x0e\n\x06result\x18\r \x01(\t\x12\x31\n\x0bjob_summary\x18\x0e \x01(\x0b\x32\x1c.cz.proto.JobSummaryLocation\x12\x31\n\x0cinput_tables\x18\x0f \x01(\x0b\x32\x1b.cz.proto.JobMeta.TableList\x12\x32\n\routput_tables\x18\x10 \x01(\x0b\x32\x1b.cz.proto.JobMeta.TableList\x12*\n\x07\x63ontent\x18\x11 \x01(\x0b\x32\x19.cz.proto.JobMeta.Content\x1a\x34\n\x0bHistoryList\x12%\n\x07history\x18\x01 \x03(\x0b\x32\x14.cz.proto.JobHistory\x1a,\n\tPartition\x12\x10\n\x08\x66ield_id\x18\x01 \x03(\r\x12\r\n\x05value\x18\x02 \x03(\t\x1a\xa5\x01\n\x05Table\x12\x11\n\tnamespace\x18\x01 \x03(\t\x12\x11\n\ttableName\x18\x02 \x01(\t\x12\x0c\n\x04size\x18\x03 \x01(\x04\x12\x0e\n\x06record\x18\x04 \x01(\x04\x12\x12\n\ncache_size\x18\x05 \x01(\x04\x12/\n\npartitions\x18\x06 \x03(\x0b\x32\x1b.cz.proto.JobMeta.Partition\x12\x13\n\x0binstance_id\x18\x07 \x01(\x03\x1a\x33\n\tTableList\x12&\n\x05table\x18\x01 \x03(\x0b\x32\x17.cz.proto.JobMeta.Table\x1a\xd9\x01\n\x07\x43ontent\x12<\n\njob_config\x18\x01 \x03(\x0b\x32(.cz.proto.JobMeta.Content.JobConfigEntry\x12#\n\x07sql_job\x18\x02 \x01(\x0b\x32\x10.cz.proto.SQLJobH\x00\x12\x17\n\x0frelease_version\x18\x03 \x01(\t\x12\x19\n\x11job_desc_location\x18\x14 \x01(\t\x1a\x30\n\x0eJobConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x05\n\x03job*i\n\tJobStatus\x12\t\n\x05SETUP\x10\x00\x12\x0c\n\x08QUEUEING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0b\n\x07SUCCEED\x10\x03\x12\x0e\n\nCANCELLING\x10\x04\x12\r\n\tCANCELLED\x10\x05\x12\n\n\x06\x46\x41ILED\x10\x06**\n\x07JobType\x12\x0b\n\x07SQL_JOB\x10\x00\x12\x12\n\x0e\x43OMPACTION_JOB\x10\x01\x42\x02P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'job_meta_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'P\001'
  _globals['_SQLJOBCONFIG_HINTENTRY']._options = None
  _globals['_SQLJOBCONFIG_HINTENTRY']._serialized_options = b'8\001'
  _globals['_JOBMETA_CONTENT_JOBCONFIGENTRY']._options = None
  _globals['_JOBMETA_CONTENT_JOBCONFIGENTRY']._serialized_options = b'8\001'
  _globals['_JOBSTATUS']._serialized_start=1648
  _globals['_JOBSTATUS']._serialized_end=1753
  _globals['_JOBTYPE']._serialized_start=1755
  _globals['_JOBTYPE']._serialized_end=1797
  _globals['_JOBCOST']._serialized_start=28
  _globals['_JOBCOST']._serialized_end=66
  _globals['_JOBHISTORY']._serialized_start=68
  _globals['_JOBHISTORY']._serialized_end=183
  _globals['_SQLJOBCONFIG']._serialized_start=186
  _globals['_SQLJOBCONFIG']._serialized_end=361
  _globals['_SQLJOBCONFIG_HINTENTRY']._serialized_start=318
  _globals['_SQLJOBCONFIG_HINTENTRY']._serialized_end=361
  _globals['_SQLJOB']._serialized_start=363
  _globals['_SQLJOB']._serialized_end=486
  _globals['_JOBSUMMARYLOCATION']._serialized_start=488
  _globals['_JOBSUMMARYLOCATION']._serialized_end=608
  _globals['_JOBMETA']._serialized_start=611
  _globals['_JOBMETA']._serialized_end=1646
  _globals['_JOBMETA_HISTORYLIST']._serialized_start=1107
  _globals['_JOBMETA_HISTORYLIST']._serialized_end=1159
  _globals['_JOBMETA_PARTITION']._serialized_start=1161
  _globals['_JOBMETA_PARTITION']._serialized_end=1205
  _globals['_JOBMETA_TABLE']._serialized_start=1208
  _globals['_JOBMETA_TABLE']._serialized_end=1373
  _globals['_JOBMETA_TABLELIST']._serialized_start=1375
  _globals['_JOBMETA_TABLELIST']._serialized_end=1426
  _globals['_JOBMETA_CONTENT']._serialized_start=1429
  _globals['_JOBMETA_CONTENT']._serialized_end=1646
  _globals['_JOBMETA_CONTENT_JOBCONFIGENTRY']._serialized_start=1591
  _globals['_JOBMETA_CONTENT_JOBCONFIGENTRY']._serialized_end=1639
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: virtual_value_info.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import expression_pb2 as expression__pb2
from . import data_type_pb2 as data__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18virtual_value_info.proto\x12\x08\x63z.proto\x1a\x10\x65xpression.proto\x1a\x0f\x64\x61ta_type.proto\"\x8e\x01\n\rConstantField\x12\x10\n\x08\x66ield_id\x18\x01 \x01(\r\x12 \n\x04type\x18\x02 \x01(\x0b\x32\x12.cz.proto.DataType\x12!\n\x05value\x18\x03 \x01(\x0b\x32\x12.cz.proto.Constant\x12\x17\n\nfield_name\x18\n \x01(\tH\x00\x88\x01\x01\x42\r\n\x0b_field_name\"Q\n\x13VirtualColumnValues\x12\'\n\x06values\x18\x01 \x03(\x0b\x32\x17.cz.proto.ConstantField\x12\x11\n\tblock_ids\x18\x02 \x03(\r\"I\n\x10VirtualValueInfo\x12\x35\n\x0evirtual_values\x18\x01 \x01(\x0b\x32\x1d.cz.proto.VirtualColumnValuesB\n\n\x08\x63z.protob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'virtual_value_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\010cz.proto'
  _globals['_CONSTANTFIELD']._serialized_start=74
  _globals['_CONSTANTFIELD']._serialized_end=216
  _globals['_VIRTUALCOLUMNVALUES']._serialized_start=218
  _globals['_VIRTUALCOLUMNVALUES']._serialized_end=299
  _globals['_VIRTUALVALUEINFO']._serialized_start=301
  _globals['_VIRTUALVALUEINFO']._serialized_end=374
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: row_operations.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import pb_util_pb2 as pb__util__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14row_operations.proto\x12\x04kudu\x1a\rpb_util.proto\"\xd1\x02\n\x0fRowOperationsPB\x12\x12\n\x04rows\x18\x02 \x01(\x0c\x42\x04\x88\xb5\x18\x01\x12\x1b\n\rindirect_data\x18\x03 \x01(\x0c\x42\x04\x88\xb5\x18\x01\"\x8c\x02\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06INSERT\x10\x01\x12\n\n\x06UPDATE\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\x12\n\n\x06UPSERT\x10\x05\x12\x11\n\rINSERT_IGNORE\x10\n\x12\x11\n\rUPDATE_IGNORE\x10\x0b\x12\x11\n\rDELETE_IGNORE\x10\x0c\x12\r\n\tSPLIT_ROW\x10\x04\x12\x15\n\x11RANGE_LOWER_BOUND\x10\x06\x12\x15\n\x11RANGE_UPPER_BOUND\x10\x07\x12\x1f\n\x1b\x45XCLUSIVE_RANGE_LOWER_BOUND\x10\x08\x12\x1f\n\x1bINCLUSIVE_RANGE_UPPER_BOUND\x10\t\x12\x0f\n\x0bREPLY_DETLA\x10\rB\x11\n\x0forg.apache.kudu')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'row_operations_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017org.apache.kudu'
  _globals['_ROWOPERATIONSPB'].fields_by_name['rows']._options = None
  _globals['_ROWOPERATIONSPB'].fields_by_name['rows']._serialized_options = b'\210\265\030\001'
  _globals['_ROWOPERATIONSPB'].fields_by_name['indirect_data']._options = None
  _globals['_ROWOPERATIONSPB'].fields_by_name['indirect_data']._serialized_options = b'\210\265\030\001'
  _globals['_ROWOPERATIONSPB']._serialized_start=46
  _globals['_ROWOPERATIONSPB']._serialized_end=383
  _globals['_ROWOPERATIONSPB_TYPE']._serialized_start=115
  _globals['_ROWOPERATIONSPB_TYPE']._serialized_end=383
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: connection_meta.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x63onnection_meta.proto\x12\x08\x63z.proto\"\x8b\x01\n\nConnection\x12\x31\n\x0f\x63onnection_type\x18\x01 \x01(\x0e\x32\x18.cz.proto.ConnectionType\x12\x39\n\x13\x63onnection_category\x18\x02 \x01(\x0e\x32\x1c.cz.proto.ConnectionCategory\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08*\x93\x01\n\x0e\x43onnectionType\x12\x12\n\x0e\x43LOUD_FUNCTION\x10\x00\x12\r\n\tLAKEHOUSE\x10\x01\x12\t\n\x05KAFKA\x10\x02\x12\x08\n\x04HIVE\x10\x03\x12\x0e\n\nCLICKHOUSE\x10\x04\x12\t\n\x05MYSQL\x10\x05\x12\x0b\n\x07POSTGRE\x10\x06\x12\r\n\tSQLSERVER\x10\x07\x12\x12\n\x0eOSS_CONNECTION\x10\x08*=\n\x12\x43onnectionCategory\x12\x13\n\x0f\x44\x41TA_CONNECTION\x10\x00\x12\x12\n\x0e\x41PI_CONNECTION\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'connection_meta_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CONNECTIONTYPE']._serialized_start=178
  _globals['_CONNECTIONTYPE']._serialized_end=325
  _globals['_CONNECTIONCATEGORY']._serialized_start=327
  _globals['_CONNECTIONCATEGORY']._serialized_end=388
  _globals['_CONNECTION']._serialized_start=36
  _globals['_CONNECTION']._serialized_end=175
# @@protoc_insertion_point(module_scope)
